# User Guide

The intake-esm user guide introduces the main concepts required for accessing Earth Sytem Model (ESM) data catalogs and loading data assets into xarray containers. This guide gives an overview of the functionality available. The guide is split into core and tutorials & examples sections.

```{toctree}
---
maxdepth: 2
caption: Core Guide
---
overview.ipynb
search.ipynb
multi-variable-assets.ipynb
```

```{toctree}
---
maxdepth: 2
caption: Tutorials & Examples
---
cmip6-tutorial.ipynb
manipulating-dataframe.ipynb
```
